/*
**   Copyright (c) Steven G. Judd 1992. 1993, 1994
**		       All Rights Reserved.
**
**  Unpublished rights reserved  under the copyright laws of the
**  United States.
**
**
**  FACILITY      : Message Queues
**  MODULE NAME   : mq_errors.mc
**
**  ABSTRACT      : Message Compiler source file for MQ messages 
** 
**  AUTHOR        : Steven G. Judd
**  CREATION DATE : 23-April-1994
**
**  MODIFICATION HISTORY :
*/
//
//  Values are 32 bit values layed out as follows:
//
//   3 3 2 2 2 2 2 2 2 2 2 2 1 1 1 1 1 1 1 1 1 1
//   1 0 9 8 7 6 5 4 3 2 1 0 9 8 7 6 5 4 3 2 1 0 9 8 7 6 5 4 3 2 1 0
//  +---+-+-+-----------------------+-------------------------------+
//  |Sev|C|R|     Facility          |               Code            |
//  +---+-+-+-----------------------+-------------------------------+
//
//  where
//
//      Sev - is the severity code
//
//          00 - Success
//          01 - Informational
//          10 - Warning
//          11 - Error
//
//      C - is the Customer code flag
//
//      R - is a reserved bit
//
//      Facility - is the facility code
//
//      Code - is the facility's status code
//
//
// Define the facility codes
//


//
// Define the severity codes
//


//
// MessageId: MQ_SUCCESS
//
// MessageText:
//
//  The requested operation completed successfully
//
#define MQ_SUCCESS                       ((long)0x21000000L)

//
// MessageId: MQ_DETACHED
//
// MessageText:
//
//  The queue has been detached
//
#define MQ_DETACHED                      ((long)0x21000001L)

//
// MessageId: MQ_DESTROYED
//
// MessageText:
//
//  The queue has been removed from the system
//
#define MQ_DESTROYED                     ((long)0x21000002L)

//
// MessageId: MQ_TRUNC
//
// MessageText:
//
//  The returned message was truncated to fit in the provided buffer
//
#define MQ_TRUNC                         ((long)0xA1000003L)

//
// MessageId: MQ_TIMEOUT
//
// MessageText:
//
//  A blocking operation has timed out
//
#define MQ_TIMEOUT                       ((long)0xA1000004L)

//
// MessageId: MQ_EXISTS
//
// MessageText:
//
//  The queue you are attempting to create already exists;
//  Use MQattach instead of MQcreate
//
#define MQ_EXISTS                        ((long)0xE1000005L)

//
// MessageId: MQ_NOMEMORY
//
// MessageText:
//
//  MQattach could not allocate memory for a queue handle
//
#define MQ_NOMEMORY                      ((long)0xE1000006L)

//
// MessageId: MQ_NOQUEUE
//
// MessageText:
//
//  MQcreate failed because no free queue data structures are available
//
#define MQ_NOQUEUE                       ((long)0xE1000007L)

//
// MessageId: MQ_NOSUCHQ
//
// MessageText:
//
//  MQattach failed because the queue named does not exist;
//  Use MQcreate instead of MQattach.
//
#define MQ_NOSUCHQ                       ((long)0xE1000008L)

//
// MessageId: MQ_BADHADDRESS
//
// MessageText:
//
//  The address provided to receive the queue handle is invalid
//
#define MQ_BADHADDRESS                   ((long)0xE1000009L)

//
// MessageId: MQ_BADHANDLE
//
// MessageText:
//
//  The queue handle is invalid
//
#define MQ_BADHANDLE                     ((long)0xE100000AL)

//
// MessageId: MQ_NOTOWNER
//
// MessageText:
//
//  The queue handle is valid but was not attached by the calling thread.
//
#define MQ_NOTOWNER                      ((long)0xE100000BL)

//
// MessageId: MQ_BADNAME
//
// MessageText:
//
//  The address of the queue name provided is invalid
//
#define MQ_BADNAME                       ((long)0xE100000CL)

//
// MessageId: MQ_NOTATTACHED
//
// MessageText:
//
//  The queue handle is valid, but the queue is not attached.
//
#define MQ_NOTATTACHED                   ((long)0xE100000DL)

//
// MessageId: MQ_PUTWOULDBLOCK
//
// MessageText:
//
//  The MqPut operation would block waiting for sufficient resources to become available.
//
#define MQ_PUTWOULDBLOCK                 ((long)0xE100000EL)

//
// MessageId: MQ_GETWOULDBLOCK
//
// MessageText:
//
//  The MqGet operation would block waiting for a message to become available.
//
#define MQ_GETWOULDBLOCK                 ((long)0xE100000FL)

//
// MessageId: MQ_JUSTTOOBIG
//
// MessageText:
//
//  The message exceeds the system maximum message size
//
#define MQ_JUSTTOOBIG                    ((long)0xE1000010L)

//
// MessageId: MQ_BADBUFADDRESS
//
// MessageText:
//
//  The message buffer address is invalid
//
#define MQ_BADBUFADDRESS                 ((long)0xE1000011L)

//
// MessageId: MQ_BADLENADDRESS
//
// MessageText:
//
//  The returned message length address is invalid
//
#define MQ_BADLENADDRESS                 ((long)0xE1000012L)

//
// MessageId: MQ_BADTYPEADDRESS
//
// MessageText:
//
//  The returned message type address is invalid
//
#define MQ_BADTYPEADDRESS                ((long)0xE1000013L)

//
// MessageId: MQ_SHUTDOWN
//
// MessageText:
//
//  The queue has been marked for removal and is shutting down: no new attaches are permitted.
//
#define MQ_SHUTDOWN                      ((long)0xE1000014L)

//
// MessageId: MQ_ALREADYATTACHED
//
// MessageText:
//
//  The Queue handle pointer passed to MqAttach appears to point to a queue handle
//  for a currently-attached queue.  Use a clean pointer or detach the queue.     
//
#define MQ_ALREADYATTACHED               ((long)0xE1000015L)

//
// MessageId: MQ_BADBLOCKPARAM
//
// MessageText:
//
//  The BLOCK parameter has a value other than MQ_BLOCKING or MQ_NONBLOCKING
//
#define MQ_BADBLOCKPARAM                 ((long)0xE1000016L)

//
// MessageId: MQ_PUTCANCELLED
//
// MessageText:
//
//  A blocking MqPut operation was cancelled by another thread in the calling process.
//
#define MQ_PUTCANCELLED                  ((long)0xE1000017L)

//
// MessageId: MQ_GETCANCELLED
//
// MessageText:
//
//  A blocking MqGet operation was cancelled by another thread in the calling process.
//
#define MQ_GETCANCELLED                  ((long)0xE1000018L)

//
// MessageId: MQ_BADGLOBALINFO
//
// MessageText:
//
//  The pointer to the MqGlobalInfo structure is invalid.
//
#define MQ_BADGLOBALINFO                 ((long)0xE1000019L)

//
// MessageId: MQ_BADQUEUEINFO
//
// MessageText:
//
//  The pointer to the MqQueueInfo structure is invalid.
//
#define MQ_BADQUEUEINFO                  ((long)0xE100001AL)

//
// MessageId: MQ_BADCALLBACK
//
// MessageText:
//
//  The pointer to the EnumQ callback routine is invalid.
//
#define MQ_BADCALLBACK                   ((long)0xE100001BL)

//
// MessageId: MQ_FAILED
//
// MessageText:
//
//  The requested operation could not be completed successfully.
//
#define MQ_FAILED                        ((long)0xE100001CL)

